built_modules = list(name for name in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;WinExtras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;Qml;Quick;QuickWidgets;Script;ScriptTools;Svg;UiTools;WebChannel;WebKit;WebSockets"
    .split(";"))

shiboken_library_soversion = str(5.6)
pyside_library_soversion = str(5.6)

version = "5.6.0~a1"
version_info = (5, 6, 0, "a", 1)

__build_date__ = '2018-05-09T12:35:20+00:00'
__build_commit_date__ = '2018-03-26T09:19:00+00:00'
__build_commit_hash__ = '333757c0733bdefe4b8c8fc73785cd2c378706d7'
__build_commit_hash_described__ = 'maya1-72-g333757c07'

# Timestamp used for snapshot build, which is part of snapshot package version.
__setup_py_package_timestamp__ = ''
