__all__ = list("Qt" + body for body in
    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;WinExtras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;Qml;Quick;QuickWidgets;Script;ScriptTools;Svg;UiTools;WebChannel;WebKit;WebSockets"
    .split(";"))
__version__ = "5.6.0~a1"
__version_info__ = (5, 6, 0, "a", 1)

__build_date__ = '2018-05-09T12:35:20+00:00'
__build_commit_date__ = '2018-03-26T09:19:00+00:00'
__build_commit_hash__ = '333757c0733bdefe4b8c8fc73785cd2c378706d7'
__build_commit_hash_described__ = 'maya1-72-g333757c07'

# Timestamp used for snapshot build, which is part of snapshot package version.
__setup_py_package_timestamp__ = ''

def _setupQtDirectories():
    import sys
    import os

    pyside_package_dir =  os.path.abspath(os.path.dirname(__file__))
    # Used by signature module.
    os.environ["PYSIDE_PACKAGE_DIR"] = pyside_package_dir

    # On Windows add the PySide2\openssl folder (if it exists) to the
    # PATH so that the SSL DLLs can be found when Qt tries to dynamically
    # load them. Tell Qt to load them and then reset the PATH.
    if sys.platform == 'win32':
        openssl_dir = os.path.join(pyside_package_dir, 'openssl')
        if os.path.exists(openssl_dir):
            path = os.environ['PATH']
            try:
                os.environ['PATH'] = os.path.join(openssl_dir, path)
                try:
                    from . import QtNetwork
                except ImportError:
                    pass
                else:
                    QtNetwork.QSslSocket.supportsSsl()
            finally:
                os.environ['PATH'] = path

_setupQtDirectories()
